Type Alias Sequence Copy item path Source pub type Sequence<N> = Vec <Item <N>>;Expand description In XPath, the Sequence is the fundamental data structure.
It is an ordered collection of Item s.
The Rust implementation is a Vector of reference counted Item s.
See SequenceTrait for methods.
pub struct Sequence<N> { }Converts to this type from the input type.
Converts to this type from the input type.
Returns the string value of the Sequence.
Renders the Sequence as XML
Renders the Sequence as XML
Renders the Sequence as JSON
Push a document’s Node on to the Sequence . This clones the node.
Calculate the effective boolean value of the Sequence
Convenience routine for integer value of the Sequence . The Sequence must be a singleton; i.e. be a single item.